@@ -32,6 +32,8 @@
 #'@example example/fragment-requirePlspm.R
 #'@example example/matrixpls.plspm-example.R
 #'@example example/fragment-endBlock.R
+#'
+
 
 
 matrixpls.plspm <-
@@ -117,12 +119,13 @@ matrixpls.plspm <-
     # 
     
     if(scaled){
-      S <- cor(dataToUse)
+      dataToUse <- scale(dataToUse)
+      S <- stats::cor(dataToUse)
       S_std <- S
     }
     else{
-      S <- cov(dataToUse)
-      S_std <- cov2cor(S)
+      S <- stats::cov(dataToUse)
+      S_std <- stats::cov2cor(S)
     } 
     
     
@@ -139,10 +142,10 @@ matrixpls.plspm <-
         # We mimic this by standardizing the data
         
         if(scaled){
-          S_boot <- cor(originalData[indices,])
+          S_boot <- stats::cor(originalData[indices,])
         }
         else{
-          S_boot <- cov(originalData[indices,])
+          S_boot <- stats::cov(originalData[indices,])
         }
         
         tryCatch(
@@ -185,7 +188,6 @@ matrixpls.plspm <-
     class(R2) <- "numeric"
     
     # PLSPM does LV score scaling differently, so we need a correction
-    
     sdv = sqrt(nrow(dataToUse)/(nrow(dataToUse)-1))   
     
     # Composite values, fittes values, and intercepts
@@ -203,17 +205,16 @@ matrixpls.plspm <-
     
     outer.mod <- sapply(lvNames, function(lvName){
       row <- which(lvNames == lvName)
-      weights <- W[row,params$outer[[row]]]*sdv
+      weights <- W[row,params$outer[[row]]] *sdv
       std.loads <- IC_std[row,params$outer[[row]]]
       communal <- std.loads^2
       redundan <- communal * R2[row]
       
       ret <- cbind(weights, std.loads, communal, redundan)
-      rownames(ret) <- gsub(paste(lvName,"=+",sep=""),"",names(weights), fixed=TRUE)
-      
+      rownames(ret) <- gsub(paste(lvName,"=+",sep=""),"",colnames(W)[params$outer[[row]]], fixed=TRUE)
       return(ret)
     }, simplify= FALSE)
-    
+
     outer.mod.dataframe <- do.call(rbind,sapply(lvNames,function(lvName){
       temp <- outer.mod[[lvName]]
       data.frame(name = rownames(temp),
@@ -248,7 +249,7 @@ matrixpls.plspm <-
       df <- nrow(params$x)-sum(regressors)-1
       se <- sqrt((1-R2[row])/(df))*c(1,sqrt(1/uniq))
       tvalue <- inner/se
-      prob <- 2*(1- pt(abs(tvalue),df))
+      prob <- 2*(1- stats::pt(abs(tvalue),df))
       
       ret <- cbind(inner, se, tvalue, prob)
       
@@ -278,7 +279,7 @@ matrixpls.plspm <-
                                                 t(parallel::mcmapply(function(x){
                                                   
                                                   # Recover the data that were used in the bootrap replications and calculate indicator variances
-                                                  sdX <- apply(dataToUse[bootIndices[x,],],2,sd)
+                                                  sdX <- apply(dataToUse[bootIndices[x,],],2,stats::sd)
                                                   boot.res$t[x,bootLoadingIndices] / sdX									 														 	
                                                 },1:params$br)),
                                                 rownames(S)),
@@ -292,9 +293,9 @@ matrixpls.plspm <-
                                              
                                              # Recover the data that were used in the bootrap replication
                                              if(scaled)
-                                               S <- cor(dataToUse[bootIndices[x,],])
+                                               S <- stats::cor(dataToUse[bootIndices[x,],])
                                              else
-                                               S <- cov(dataToUse[bootIndices[x,],])
+                                               S <- stats::cov(dataToUse[bootIndices[x,],])
                                              
                                              # Reconstruct the matrices
                                              W <- matrix(0,nrow(W.model),ncol(W.model))
@@ -392,20 +393,33 @@ matrixpls.plspm <-
     
     effs <- effects(matrixpls.res)
     
+    # Fill in missing rows
+    
+    effs <- lapply(effs,function(eff){
+      ns <- setdiff(rownames(nativeModel$inner),rownames(eff))
+      for(n in ns){
+        eff <- rbind(0,eff)
+        rownames(eff)[1] <- n
+      }
+      eff[rownames(nativeModel$inner),colnames(nativeModel$inner)]
+    })
+    
     effects <- data.frame(relationships = pathLabels,
-                          direct = effs$Direct[pathIndices[-1,]],
-                          indirect = effs$Indirect[pathIndices[-1,]], 
-                          total = effs$Total[pathIndices[-1,]])
+                          direct = effs$Direct[pathIndices],
+                          indirect = effs$Indirect[pathIndices], 
+                          total = effs$Total[pathIndices])
 
     unidim <- data.frame(Mode = params$modes,
                          MVs = blocks,
                          C.alpha = ifelse(params$modes == "A",
                                           sapply(params$outer,function(indices){
+                                            if(length(indices) == 1) return(1)
                                             psych::alpha(S[indices,indices])$total[[2]]
                                           }, simplify = TRUE),
                                           0),
                          DG.rho = ifelse(params$modes == "A",
                                          sapply(params$outer,function(indices){
+                                           if(length(indices) == 1) return(1)
                                            pc <- psych::principal(S[indices,indices])
                                            std.loads <- pc$loadings
                                            numer.rho <- sum(std.loads)^2
@@ -415,22 +429,33 @@ matrixpls.plspm <-
                                          0),
                          
                          eig.1st = sapply(params$outer,function(indices){
+                           if(length(indices) == 1) return(1)
                            eigen(S_std[indices,indices])$values[1]
                          }, simplify = TRUE),   
                          eig.2nd = sapply(params$outer,function(indices){
+                           if(length(indices) == 1) return(0)
                            eigen(S_std[indices,indices])$values[2]
                          }, simplify = TRUE))
     
     # Goodness of Fit is square root of product of mean communality and mean R2
-    
+    # plspm calulates this a bit differently
+
     gof <- gof(matrixpls.res)
     class(gof) <- "numeric"
     
     # Crossloadings are the IC matrix
-    
-    crossloadings <- cbind(outer.mod.dataframe[,1:2],t(IC)/sqrt(diag(S)))
+
+    crossloadings <- cbind(outer.mod.dataframe[,1:2],
+                           t(IC[,as.character(outer.mod.dataframe$name)])/
+                             sqrt(diag(S))[as.character(outer.mod.dataframe$name)])
+
     rownames(crossloadings) <- NULL
     
+    data <- as.data.frame(data)
+    attr(data,"row.names") <- as.character(attr(data,"row.names"))
+    
+    manifests <- scale(data, scale=FALSE)
+
     res = list(outer_model = outer.mod.dataframe, 
                inner_model = inner.mod, 
                path_coefs = inner, 
@@ -441,8 +466,8 @@ matrixpls.plspm <-
                unidim = unidim, 
                gof = gof, 
                boot = boot, 
-               data = as.data.frame(data), 
-               manifests = scale(data, scale=FALSE),
+               data = data, 
+               manifests = manifests,
                model = model)
     
     #		out.weights = out.weights, 
@@ -569,9 +594,9 @@ get_bootDataFrame <- function(t0, t, rownames){
   
   ret <- data.frame(Original = t0, 
                     Mean.Boot = apply(t, 2, mean), 
-                    Std.Error = apply(t, 2, sd), 
-                    perc.025 = apply(t, 2, quantile, 0.025),
-                    perc.975 = apply(t, 2, quantile, 0.975))
+                    Std.Error = apply(t, 2, stats::sd), 
+                    perc.025 = apply(t, 2, stats::quantile, 0.025),
+                    perc.975 = apply(t, 2, stats::quantile, 0.975))
   
   rownames(ret) <- rownames
   
